﻿// Learn more about F# at http://fsharp.net

namespace XSLTConvertor.Extension

open System
open XSLTConvertor.Extension

[<ExtensionAttribute("urn:fs_common")>]
type FsCommon public () =
    /// '_'をワード単位としてワード先頭文字を大文字に変更する
    member public this.Proper (text : string) =
        if String.IsNullOrEmpty(text) then text
        elif text.IndexOf('_') < 0 then text
        else
            List.ofArray(text.Split('_'))
                |> List.map (fun a -> a.[0].ToString().ToUpper() + a.[1..])
                |> List.fold (fun s n -> s + n) ""
                
    /// Javaローカル変数名の命名規則に変換した文字列を取得
    member public this.GetLocalName (text : string) =
        let t = this.Proper(text)
        t.[0].ToString().ToLower() + t.[1..]

    /// Javaの型名を取得
    member public this.GetTypeText (type_text : string, size_text : string) =
        let successful, result = Decimal.TryParse(size_text)
        match type_text.ToUpper() with
            | "DATE" -> "Date"
            | "TIMESTAMP" -> "Timestamp"
            | "NUMBER" ->
                if result <= 7M then
                    "Integer"
                else
                    "Long"
            | _ -> "String"
                
    /// String.Format のキャプション1個を置き換えする機能
    member public this.Format (text : string, a : string) =
        this.Format(text, a, "", "", "", "", "", "", "", "", "")
                
    /// String.Format のキャプション2個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string) =
        this.Format(text, a, b, "", "", "", "", "", "", "", "")
                
    /// String.Format のキャプション3個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string) =
        this.Format(text, a, b, c, "", "", "", "", "", "", "")
                
    /// String.Format のキャプション4個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string) =
        this.Format(text, a, b, c, d, "", "", "", "", "", "")
                
    /// String.Format のキャプション5個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string) =
        this.Format(text, a, b, c, d, e, "", "", "", "", "")
                
    /// String.Format のキャプション6個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string,
                                    f : string) =
        this.Format(text, a, b, c, d, e, f, "", "", "", "")
                
    /// String.Format のキャプション7個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string,
                                    f : string, g : string) =
        this.Format(text, a, b, c, d, e, f, g, "", "", "")

    /// String.Format のキャプション8個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string,
                                    f : string, g : string, h : string) =
        this.Format(text, a, b, c, d, e, f, g, h, "", "")

    /// String.Format のキャプション9個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string,
                                    f : string, g : string, h : string, i : string) =
        this.Format(text, a, b, c, d, e, f, g, h, i, "")

    /// String.Format のキャプション10個を置き換えする機能
    member public this.Format (text : string,
                                    a : string, b : string, c : string, d : string, e : string,
                                    f : string, g : string, h : string, i : string, j : string) =
        let list = [ a; b; c; d; e; f; g; h; i; j ];
        // 再帰関数
        let rec rep (text : string, list : string list, count : int) =
            let p = "{" + count.ToString() + "}"
            let ret = text.Replace(p, list.[count])
            if 0 = count then
                ret
            else
                rep (ret, list, count - 1)
        rep(text, list, 9)